==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/AzureFilePersistentVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AzureFilePersistentVolumeSourceBuilder extends AzureFilePersistentVolumeSourceFluentImpl<AzureFilePersistentVolumeSourceBuilder> implements VisitableBuilder<AzureFilePersistentVolumeSource,AzureFilePersistentVolumeSourceBuilder>{
  public AzureFilePersistentVolumeSourceBuilder() {
    this(false);
  }
  public AzureFilePersistentVolumeSourceBuilder(Boolean validationEnabled) {
    this(new AzureFilePersistentVolumeSource(), validationEnabled);
  }
  public AzureFilePersistentVolumeSourceBuilder(AzureFilePersistentVolumeSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public AzureFilePersistentVolumeSourceBuilder(AzureFilePersistentVolumeSourceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AzureFilePersistentVolumeSource(), validationEnabled);
  }
  public AzureFilePersistentVolumeSourceBuilder(AzureFilePersistentVolumeSourceFluent<?> fluent,AzureFilePersistentVolumeSource instance) {
    this(fluent, instance, false);
  }
  public AzureFilePersistentVolumeSourceBuilder(AzureFilePersistentVolumeSourceFluent<?> fluent,AzureFilePersistentVolumeSource instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withReadOnly(instance.getReadOnly());
      fluent.withSecretName(instance.getSecretName());
      fluent.withSecretNamespace(instance.getSecretNamespace());
      fluent.withShareName(instance.getShareName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public AzureFilePersistentVolumeSourceBuilder(AzureFilePersistentVolumeSource instance) {
    this(instance,false);
  }
  public AzureFilePersistentVolumeSourceBuilder(AzureFilePersistentVolumeSource instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withReadOnly(instance.getReadOnly());
      this.withSecretName(instance.getSecretName());
      this.withSecretNamespace(instance.getSecretNamespace());
      this.withShareName(instance.getShareName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  AzureFilePersistentVolumeSourceFluent<?> fluent;
  Boolean validationEnabled;
  public AzureFilePersistentVolumeSource build() {
    AzureFilePersistentVolumeSource buildable = new AzureFilePersistentVolumeSource(fluent.getReadOnly(),fluent.getSecretName(),fluent.getSecretNamespace(),fluent.getShareName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-core-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/AzureFilePersistentVolumeSourceBuilder.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AzureFilePersistentVolumeSourceBuilder extends AzureFilePersistentVolumeSourceFluent<AzureFilePersistentVolumeSourceBuilder> implements VisitableBuilder<AzureFilePersistentVolumeSource,AzureFilePersistentVolumeSourceBuilder>{
  public AzureFilePersistentVolumeSourceBuilder() {
    this(false);
  }
  public AzureFilePersistentVolumeSourceBuilder(Boolean validationEnabled) {
    this(new AzureFilePersistentVolumeSource(), validationEnabled);
  }
  public AzureFilePersistentVolumeSourceBuilder(AzureFilePersistentVolumeSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public AzureFilePersistentVolumeSourceBuilder(AzureFilePersistentVolumeSourceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AzureFilePersistentVolumeSource(), validationEnabled);
  }
  public AzureFilePersistentVolumeSourceBuilder(AzureFilePersistentVolumeSourceFluent<?> fluent,AzureFilePersistentVolumeSource instance) {
    this(fluent, instance, false);
  }
  public AzureFilePersistentVolumeSourceBuilder(AzureFilePersistentVolumeSourceFluent<?> fluent,AzureFilePersistentVolumeSource instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new AzureFilePersistentVolumeSource());

    if (instance != null) {
      fluent.withReadOnly(instance.getReadOnly());
      fluent.withSecretName(instance.getSecretName());
      fluent.withSecretNamespace(instance.getSecretNamespace());
      fluent.withShareName(instance.getShareName());
      fluent.withReadOnly(instance.getReadOnly());
      fluent.withSecretName(instance.getSecretName());
      fluent.withSecretNamespace(instance.getSecretNamespace());
      fluent.withShareName(instance.getShareName());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public AzureFilePersistentVolumeSourceBuilder(AzureFilePersistentVolumeSource instance) {
    this(instance,false);
  }
  public AzureFilePersistentVolumeSourceBuilder(AzureFilePersistentVolumeSource instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new AzureFilePersistentVolumeSource());

    if (instance != null) {
      this.withReadOnly(instance.getReadOnly());
      this.withSecretName(instance.getSecretName());
      this.withSecretNamespace(instance.getSecretNamespace());
      this.withShareName(instance.getShareName());
      this.withReadOnly(instance.getReadOnly());
      this.withSecretName(instance.getSecretName());
      this.withSecretNamespace(instance.getSecretNamespace());
      this.withShareName(instance.getShareName());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  AzureFilePersistentVolumeSourceFluent<?> fluent;
  Boolean validationEnabled;
  public AzureFilePersistentVolumeSource build() {
    AzureFilePersistentVolumeSource buildable = new AzureFilePersistentVolumeSource(fluent.getReadOnly(),fluent.getSecretName(),fluent.getSecretNamespace(),fluent.getShareName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
